summaryrefslogtreecommitdiff
path: root/src/lib/video_source.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-04-15 16:24:03 +0100
committerCarl Hetherington <cth@carlh.net>2013-04-15 16:24:03 +0100
commit3f2365fcf3a1ffc50901eb2e4af246aa4c83e272 (patch)
tree289a2fdbea44d1f5d8326601972e259e65aa0d80 /src/lib/video_source.h
parenta00ebbc68438e84076c65e99d0e70403afb4407d (diff)
Repair very bad merge. Mysterious.
Diffstat (limited to 'src/lib/video_source.h')
-rw-r--r--src/lib/video_source.h23
1 files changed, 21 insertions, 2 deletions
diff --git a/src/lib/video_source.h b/src/lib/video_source.h
index 893629160..705b0023a 100644
--- a/src/lib/video_source.h
+++ b/src/lib/video_source.h
@@ -29,11 +29,12 @@
#include "util.h"
class VideoSink;
+class TimedVideoSink;
class Subtitle;
class Image;
/** @class VideoSink
* @param A class that emits video data.
*/
class VideoSource
{
@@ -49,4 +50,22 @@ public:
void connect_video (boost::shared_ptr<VideoSink>);
};
+/** @class TimedVideoSource
+ * @param A class that emits video data with timestamps.
+ */
+class TimedVideoSource
+{
+public:
+
+ /** Emitted when a video frame is ready.
+ * First parameter is the video image.
+ * Second parameter is true if the image is the same as the last one that was emitted.
+ * Third parameter is either 0 or a subtitle that should be on this frame.
+ * Fourth parameter is the source timestamp of this frame.
+ */
+ boost::signals2::signal<void (boost::shared_ptr<Image>, bool, boost::shared_ptr<Subtitle>, double)> Video;
+
+ void connect_video (boost::shared_ptr<TimedVideoSink>);
+};
+
#endif
@@ -29,11 +29,12 @@
class Subtitle;
class Image;
-/** @class VideoSink
- * @param A class that emits video data.
+/** @class VideoSource
+ * @param A class that emits video data without timestamps.
*/
class VideoSource